@@ -55,6 +55,38 @@ function Pyrone_getSelectedRows(table_id) {
 	return res;
 }
 
+function Pyrone_selectDeselectAll(table_id)
+{
+	var table = $('#'+table_id);
+	if (!table.get(0)) {
+		return false;
+	}
+
+	var nodes = table.find('input[class=list-cb]').filter('[disabled!=disabled]'),
+		checked_count = 0,
+		not_checked_count = 0;
+
+	nodes.each(function(ind, el) {
+		if (el.checked) {
+			checked_count++;
+		} else {
+			not_checked_count++;
+		}
+	});
+
+	var new_state;
+
+	if (checked_count > 0 && not_checked_count == 0) {
+		// i.e. all rows selected, so clear selection
+		new_state = false;
+	} else {
+		// select all otherwise
+		new_state = true;
+	}
+	nodes.prop('checked', new_state);
+}
+
+
 /**
  * @param {String} target_id id of node where append confirm box
  * @param {Function} callback required callback to be called when user clicks confirm box
@@ -658,7 +690,6 @@ function Pyrone_editor_unindent(id)
 		result.push(line);
 	});
 
-	console.log('success', success);
 	if (success === true) {
 		var new_selection = result.join('\n');
 		f.fieldSelection(new_selection);
@@ -696,6 +727,55 @@ function Pyrone_editor_indent(id)
 		result.push('    ' + line);
 	});
 
+	var new_selection = result.join('\n');
+	f.fieldSelection(new_selection);
+}
+
+function Pyrone_editor_wrap(id, wrap_in)
+{
+	var f = $('#'+id),
+		sel = f.fieldSelection();
+
+	if (sel.length == 0) {
+		return;
+	}
+
+	var text = wrap_in + sel.text + wrap_in;
+
+	f.fieldSelection(text);
+}
+
+function Pyrone_editor_blockquote(id)
+{
+	var f = $('#'+id);
+
+	if (f.length == 0) {
+		return;
+	}
+
+	var sel = f.fieldSelection();
+
+	if (sel.length == 0) {
+		return;
+	}
+
+	var field_value = f.val(),
+		c;
+
+	if (sel.start != 0) {
+		// i.e. text starts somewhere in the middle of line
+		c = field_value.charCodeAt(sel.start - 1);
+		if (c != 10 && c != 13) {
+			return;
+		}
+	}
+
+	var result = [];
+
+	$.each(sel.text.split(/(?:\r\n|\r|\n)/m), function(ind, line) {
+		result.push('> ' + line);
+	});
+
 	var new_selection = result.join('\n');
 	f.fieldSelection(new_selection);
 }
\ No newline at end of file
